Package: pdInfoBuilder
Title: Platform Design Information Package Builder
Description: Builds platform design information packages.
  These consist of a SQLite database containing feature-level
  data such as x, y position on chip and
  featureSet ID. The database also incorporates featureSet-level
  annotation data. The products of this packages are used by the oligo pkg.
Version: 1.76.0
Author: Seth Falcon, Vince Carey, Matt Settles, Kristof de Beuf, Benilton Carvalho
Maintainer: Benilton Carvalho <benilton@unicamp.br>
LazyLoad: yes
Depends: R (>= 3.2.0), methods, Biobase (>= 2.27.3), RSQLite (>=
        1.0.0), affxparser (>= 1.39.4), oligo (>= 1.31.5)
Imports: Biostrings (>= 2.35.12), BiocGenerics (>= 0.13.11), DBI (>=
        0.3.1), IRanges (>= 2.1.43), oligoClasses (>= 1.29.6),
        S4Vectors (>= 0.5.22)
License: Artistic-2.0
Collate: AllClasses.R AllGenerics.R initialize-methods.R utils.R
        schema.R initDb.R initDb.snp6.R pmmmBlockToMat.R loaders.R
        loaders.snp6.R makePdInfoPackage-methods.R chipName-methods.R
        getGeometry-methods.R pdBuilderV2TiledRegion.R
        pdBuilderV2ExonTranscription.R pdBuilderV2Gene.R
        pdBuilderV2HTA2.R pdBuilderV2AffyTiling.R
        pdBuilderV2NgsExpression.R pdBuilderV2AffyExpressionHT.R
        pdBuilderV2AffySNP.R pdBuilderV2AffySNPCNV.R pdBuilderV2miRNA.R
        pdBuilderV3GenericArray.R pdBuilderV2Clariom.R
biocViews: Annotation, Infrastructure
git_url: https://git.bioconductor.org/packages/pdInfoBuilder
git_branch: RELEASE_3_23
git_last_commit: 699dfd5
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-28 23:05:43 UTC; biocbuild
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-29 04:54:18 UTC; unix
