Package: @PKGNAME@
Title: Platform Design Info for @MANUF@ @CHIPNAME@
Description: Platform Design Info for @MANUF@ @CHIPNAME@
Version: @VERSION@
Author: @AUTHOR@
Maintainer: @AUTHOR@ <@AUTHOREMAIL@>
LazyLoad: yes
Depends: R (>= 3.2.0),
         Biostrings (>= 2.35.12),
         methods,
         RSQLite (>= 1.0.0),
         oligoClasses (>= 1.29.6),
         oligo (>= 1.31.5),
         DBI (>= 0.3.1),
         IRanges (>= 2.1.43),
         S4Vectors (>= 0.5.22)
License: @LIC@
biocViews: AnnotationData, oligo
ZipData: no
