useDynLib("pdInfoBuilder")

importClassesFrom(Biobase, ScalarCharacter)

importMethodsFrom(DBI, dbDriver)

importMethodsFrom(methods, initialize)

importMethodsFrom(RSQLite, dbBegin, dbClearResult, dbCommit,
                  dbConnect, dbDisconnect, dbGetPreparedQuery,
                  dbGetQuery, dbListTables, dbSendPreparedQuery,
                  dbWriteTable)

importFrom(affxparser, readBpmap, readCdf, readCdfHeader,
           readCdfUnitNames, readCelHeader, readClf, readClfHeader,
           readPgf, readPgfHeader)

importFrom(Biobase, createPackage)

importFrom(Biostrings, DNAStringSet)

importFrom(methods, callNextMethod, new, slot)

importFrom(oligo, cleanPlatformName)

importFrom(RSQLite, SQLite)

importFrom(S4Vectors, DataFrame)

importFrom(utils, installed.packages, read.csv, read.delim, read.table)

exportClasses(
              "AffyExpressionPDInfoPkgSeed",
              "AffyTilingPDInfoPkgSeed",
              "AffySNPPDInfoPkgSeed",
              "AffySNPPDInfoPkgSeed2",
              "AffySNPCNVPDInfoPkgSeed",
              "AffySNPCNVPDInfoPkgSeed2",
              "AffyExonPDInfoPkgSeed",
              "AffyGenePDInfoPkgSeed",
              "NgsExpressionPDInfoPkgSeed",
              "NgsTilingPDInfoPkgSeed"
              )

exportMethods(
              "chipName",
              "getGeometry",
              "makePdInfoPackage"
              )


export('cdf2table', 'sequenceParser')
