### R code from vignette source 'howto-AffymetrixMapping.Rnw'

###################################################
### code chunk number 1: setup
###################################################
options(width=60)
options(continue=" ")
options(prompt="R> ")


###################################################
### code chunk number 2: build1 (eval = FALSE)
###################################################
## library("pdInfoBuilder")
## cdfFile <- "Mapping250K_Nsp.cdf"
## csvAnno <- "Mapping250K_Nsp_annot.csv"
## csvSeq <- "Mapping250K_Nsp_probe_tab"
## 
## pkg <- new("AffySNPPDInfoPkgSeed", 
##            version="0.1.5",
##            author="Seth Falcon", email="sfalcon@fhcrc.org",
##            biocViews="AnnotationData",
##            genomebuild="NCBI Build 35, May 2004",
##            cdfFile=cdfFile, csvAnnoFile=csvAnno, csvSeqFile=csvSeq)
## 
## makePdInfoPackage(pkg, destDir=".")
## 
