\name{@PKGNAME@}
\Rdversion{1.1}
\docType{package}
\alias{@PKGNAME@}
\title{
  Annotation package for @PKGNAME@.
}
\description{
  Annotation package for @PKGNAME@ built with pdInfoBuilder.
}
\details{
  This package is to be used in conjunction with the oligo package.
}
\keyword{package}
